@@ -2,7 +2,7 @@
 ###
 ###               Tukey multiple comparisons for R
 ###
-### Copyright 2000-2000  Douglas M. Bates <bates@stat.wisc.edu>
+### Copyright 2000-2001  Douglas M. Bates <bates@stat.wisc.edu>
 ###
 ### This file is made available under the terms of the GNU General
 ### Public License, version 2, or at your option, any later version,
@@ -76,23 +76,24 @@ print.Tukey <- function(x, ...)
     print.default(unclass(x), ...)
 }
 
-plot.Tukey <- function(x, ...)
+plot.Tukey <- function (x, ...)
 {
     for (i in seq(along = x)) {
         xi <- x[[i]]
         yvals <- nrow(xi):1
-        plot(c(xi[, "lwr"], xi[, "upr"]), rep(yvals, 2),
-             type = "n", axes = FALSE, xlab = "", ylab = "")
-        axis(1)
-        axis(2, at = nrow(xi):1, labels = dimnames(xi)[[1]], srt = 0)
+        plot(c(xi[, "lwr"], xi[, "upr"]), rep(yvals, 2), type = "n",
+             axes = FALSE, xlab = "", ylab = "", ...)
+        axis(1, ...)
+        axis(2, at = nrow(xi):1, labels = dimnames(xi)[[1]],
+             srt = 0, ...)
         abline(h = yvals, lty = 1, lwd = 0, col = "lightgray")
-        abline(v = 0, lty = 2, lwd = 0)
-        segments(xi[, "lwr"], yvals, xi[, "upr"], yvals)
-        segments(as.vector(xi), rep(yvals - 0.1, 3),
-                 as.vector(xi), rep(yvals + 0.1, 3))
-        title(main = paste(format(100*attr(x, "conf.level"), 2),
-              "% family-wise confidence level\n", sep=""),
+        abline(v = 0, lty = 2, lwd = 0, ...)
+        segments(xi[, "lwr"], yvals, xi[, "upr"], yvals, ...)
+        segments(as.vector(xi), rep(yvals - 0.1, 3), as.vector(xi),
+                 rep(yvals + 0.1, 3), ...)
+        title(main = paste(format(100 * attr(x, "conf.level"),
+              2), "% family-wise confidence level\n", sep = ""),
               xlab = paste("Differences in mean levels of", names(x)[i]))
+        box()
     }
-    box()
 }
